@@ -30,20 +30,15 @@ SharingPluginInterfaceSendResult vkontakte_send (SharingTransfer* transfer,
     SharingEntry *entry = sharing_transfer_get_entry(transfer);
     SharingAccount* account = sharing_entry_get_account(entry);
     SharingEntryMedia* media = NULL;
-    //SharingHTTP * http = sharing_http_new ();
-    gchar* error;
 
     /** get selected album **/
     const gchar* album =  sharing_entry_get_option (entry, "album");
 
-    const gchar* proxy_host = con_ic_connection_get_proxy_host(con,
-                        CON_IC_PROXY_PROTOCOL_HTTP);
-    gint proxy_port = con_ic_connection_get_proxy_port(con,
-                        CON_IC_PROXY_PROTOCOL_HTTP);
-
     gchar* account_name = sharing_account_get_param (account, "username");
 
-    if(!libvk_init((gchar*) proxy_host, proxy_port, account_name)){
+    msa_print("%s:%d:%s: account=%s, album=%s\n", __FILE__, __LINE__, __FUNCTION__, account_name, album);
+
+    if(!libvk_init(con, account_name)){
         return SHARING_SEND_ERROR_UNKNOWN;
     }
 
@@ -62,16 +57,23 @@ SharingPluginInterfaceSendResult vkontakte_send (SharingTransfer* transfer,
             sharing_element = g_slist_next(sharing_element)) {
         media = sharing_element->data;
 
-        /* send photo */
-        path_to_photo = sharing_entry_media_get_localpath(media);
-        file_name = sharing_entry_media_get_filename(media);
-        if (FALSE == libvk_uploadPhoto((gchar*)album, (gchar*)path_to_photo, file_name)) {
-            msa_print("%s:%d:%s: error upload photo\n", __FILE__, __LINE__, __FUNCTION__);
-            g_free(file_name);
-            libvk_uninit();
-            return SHARING_SEND_ERROR_UNKNOWN;
+	if (!sharing_entry_media_get_sent(media))
+	{
+    	    /* send photo */
+    	    path_to_photo = sharing_entry_media_get_localpath(media);
+    	    file_name = sharing_entry_media_get_filename(media);
+    	    msa_print("%s:%d:%s: upload image: %s\n", __FILE__, __LINE__, __FUNCTION__, file_name);
+    	    if (FALSE == libvk_uploadPhoto((gchar*)album, (gchar*)path_to_photo, file_name)) {
+        	msa_print("%s:%d:%s: error upload photo\n", __FILE__, __LINE__, __FUNCTION__);
+        	g_free(file_name);
+        	libvk_uninit();
+        	return SHARING_SEND_ERROR_UNKNOWN;
+    	    } else {
+        	/* If success mark media as sent */
+        	sharing_entry_media_set_sent (media, TRUE);
+    	    }
+    	    g_free(file_name);
         }
-        g_free(file_name);
     }
 
     msa_print("%s:%d:%s: finish upload photo\n", __FILE__, __LINE__, __FUNCTION__);
